'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PickerHeader = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _semanticUiReact = require('semantic-ui-react');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _lib = require('../lib');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cellStyles = function cellStyles(bottomBorder) {
  return {
    border: 'none',
    borderBottom: bottomBorder ? '1px solid rgba(34,36,38,.1)' : 'none'
  };
};

function PickerHeader(props) {
  var onNextBtnClick = props.onNextBtnClick,
      onPrevBtnClick = props.onPrevBtnClick,
      activeDate = props.activeDate,
      activeDatesRange = props.activeDatesRange,
      activeYears = props.activeYears,
      activeYear = props.activeYear,
      includeDay = props.includeDay,
      showWeeks = props.showWeeks,
      width = props.width,
      onDateClick = props.onDateClick,
      nextDisabled = props.nextDisabled,
      prevDisabled = props.prevDisabled;

  var rest = (0, _lib.getUnhandledProps)(PickerHeader, props);

  var _getWeekDayHeaders = function _getWeekDayHeaders() {
    return (0, _lib.getWeekDays)().map(function (weekDay) {
      return _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        {
          key: weekDay,
          style: cellStyles(true),
          colSpan: '1' },
        weekDay
      );
    });
  };

  _getWeekDayHeaders.handledProps = [];
  var getRangeRow = function getRangeRow() {
    var getContent = function getContent() {
      var start = activeDatesRange.start,
          end = activeDatesRange.end;

      if (start && end) {
        return start.format('MMM DD, YYYY') + ' - ' + end.format('MMM DD, YYYY');
      }
      if (start) {
        return start.format('MMMM DD, YYYY') + ' - ' + '. . .';
      }
      return '. . . - . . .';
    };
    return _react2.default.createElement(
      _semanticUiReact.Table.Row,
      null,
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { style: cellStyles(), colSpan: '7' },
        getContent()
      )
    );
  };

  getRangeRow.handledProps = [];
  var getContent = function getContent() {
    if (activeYears) {
      return activeYears.start + ' - ' + activeYears.end;
    }

    if (activeYear) {
      return activeYear;
    }

    if (activeDate) {
      return includeDay ? activeDate.format('MMMM DD, YYYY') : activeDate.format('MMMM YYYY');
    }
  };

  var headerCellStyle = { cursor: 'pointer ' };
  var nextBtnDisabled = _lodash2.default.isFunction(nextDisabled) && nextDisabled();
  var prevBtnDisabled = _lodash2.default.isFunction(prevDisabled) && prevDisabled();
  var cursorStylePrev = {
    cursor: prevBtnDisabled ? 'auto' : 'pointer'
  };
  var cursorStyleNext = {
    cursor: nextBtnDisabled ? 'auto' : 'pointer'
  };

  return _react2.default.createElement(
    _semanticUiReact.Table.Header,
    rest,
    activeDatesRange && getRangeRow(),
    _react2.default.createElement(
      _semanticUiReact.Table.Row,
      null,
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { style: cellStyles(!showWeeks), colSpan: '1' },
        _react2.default.createElement(_semanticUiReact.Icon, {
          fitted: true,
          style: cursorStylePrev,
          disabled: prevBtnDisabled,
          onClick: prevBtnDisabled ? undefined : onPrevBtnClick,
          name: 'chevron left' })
      ),
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        {
          onClick: onDateClick,
          style: cellStyles(!showWeeks),
          colSpan: (parseInt(width) - 2).toString() },
        _react2.default.createElement(
          'span',
          { style: headerCellStyle },
          getContent()
        )
      ),
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { style: cellStyles(!showWeeks), colSpan: '1' },
        _react2.default.createElement(_semanticUiReact.Icon, {
          fitted: true,
          style: cursorStyleNext,
          disabled: nextBtnDisabled,
          onClick: nextBtnDisabled ? undefined : onNextBtnClick,
          name: 'chevron right' })
      )
    ),
    showWeeks && _react2.default.createElement(
      _semanticUiReact.Table.Row,
      null,
      _getWeekDayHeaders()
    )
  );
}

PickerHeader.handledProps = ['activeDate', 'activeDatesRange', 'activeYear', 'activeYears', 'className', 'includeDay', 'nextDisabled', 'onDateClick', 'onNextBtnClick', 'onPrevBtnClick', 'prevDisabled', 'showWeeks', 'width'];


PickerHeader.defaultProps = {
  includeDay: false,
  showWeeks: false
};

exports.default = PickerHeader;
exports.PickerHeader = PickerHeader;